Re-exports
pub use cose::format_error;
Modules
Constants
Statics
Traits
- Canister
Caller - A trait for interacting with canisters
Functions
- to_
cbor_ bytes - Converts a serializable object to CBOR-encoded bytes
- try_
to_ cbor_ bytes - Converts a serializable object to CBOR-encoded bytes.
- validate_
principals - Validates a set of principals
- validate_
principals_ not_ anonymous - Validates that a principal set does not contain anonymous principal.
- validate_
str - Validates a string against naming conventions
Type Aliases
- BoxError
- A type alias for a boxed error that is thread-safe and sendable across threads. This is commonly used as a return type for functions that can return various error types.